summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNoel Grandin <noelgrandin@gmail.com>2021-06-11 22:34:07 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2021-06-12 08:37:55 +0200
commit715797bc2b361960d70095d6e6d289de063e1d5c (patch)
tree8fda3569e3690a14b46146285177bfacdbbbb82b
parent6b349bcc32336664a31deed3f4463e40dd028f63 (diff)
Backgrd -> Background
Change-Id: I55bccacfe6c6b44570a24e9f5125e40a1a83d6ea Reviewed-on: https://gerrit.libreoffice.org/c/core/+/117073 Tested-by: Jenkins Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
-rw-r--r--sw/inc/dcontact.hxx2
-rw-r--r--sw/inc/fesh.hxx4
-rw-r--r--sw/source/core/access/accpara.cxx6
-rw-r--r--sw/source/core/draw/dcontact.cxx10
-rw-r--r--sw/source/core/frmedt/feshview.cxx18
-rw-r--r--sw/source/core/inc/pagefrm.hxx4
-rw-r--r--sw/source/core/layout/paintfrm.cxx34
-rw-r--r--sw/source/core/view/vdraw.cxx6
-rw-r--r--sw/source/filter/ww8/ww8graf.cxx6
-rw-r--r--sw/source/uibase/uiview/viewdraw.cxx2
10 files changed, 46 insertions, 46 deletions
diff --git a/sw/inc/dcontact.hxx b/sw/inc/dcontact.hxx
index c596a61e4980..1884ddc5746d 100644
--- a/sw/inc/dcontact.hxx
+++ b/sw/inc/dcontact.hxx
@@ -403,7 +403,7 @@ class SAL_DLLPUBLIC_RTTI SwDrawContact final : public SwContact
SwDrawVirtObj* AddVirtObj(SwFrame const& rAnchorFrame);
- void NotifyBackgrdOfAllVirtObjs( const tools::Rectangle* pOldBoundRect );
+ void NotifyBackgroundOfAllVirtObjs( const tools::Rectangle* pOldBoundRect );
/** get data collection of anchored objects, handled by with contact */
diff --git a/sw/inc/fesh.hxx b/sw/inc/fesh.hxx
index 7a1e5e60f685..281098a9e6a0 100644
--- a/sw/inc/fesh.hxx
+++ b/sw/inc/fesh.hxx
@@ -778,7 +778,7 @@ public:
std::vector< OUString > & aNextPageVec,
std::vector< OUString > & aRestVec);
- /** SwFEShell::GetShapeBackgrd
+ /** SwFEShell::GetShapeBackground
method determines background color of the page the selected drawing
object is on and returns this color.
@@ -788,7 +788,7 @@ public:
@returns an object of class Color
*/
- Color GetShapeBackgrd() const;
+ Color GetShapeBackground() const;
/** Is default horizontal text direction for selected drawing object right-to-left
diff --git a/sw/source/core/access/accpara.cxx b/sw/source/core/access/accpara.cxx
index 555675d33473..ff2afb3aecc5 100644
--- a/sw/source/core/access/accpara.cxx
+++ b/sw/source/core/access/accpara.cxx
@@ -803,13 +803,13 @@ static bool lcl_GetBackgroundColor( Color & rColor,
const SwFrame* pFrame,
SwCursorShell* pCursorSh )
{
- const SvxBrushItem* pBackgrdBrush = nullptr;
+ const SvxBrushItem* pBackgroundBrush = nullptr;
std::optional<Color> xSectionTOXColor;
SwRect aDummyRect;
drawinglayer::attribute::SdrAllFillAttributesHelperPtr aFillAttributes;
if ( pFrame &&
- pFrame->GetBackgroundBrush( aFillAttributes, pBackgrdBrush, xSectionTOXColor, aDummyRect, false, /*bConsiderTextBox=*/false ) )
+ pFrame->GetBackgroundBrush( aFillAttributes, pBackgroundBrush, xSectionTOXColor, aDummyRect, false, /*bConsiderTextBox=*/false ) )
{
if ( xSectionTOXColor )
{
@@ -818,7 +818,7 @@ static bool lcl_GetBackgroundColor( Color & rColor,
}
else
{
- rColor = pBackgrdBrush->GetColor();
+ rColor = pBackgroundBrush->GetColor();
return true;
}
}
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index 579866cedcbe..1f0632850ad2 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -897,7 +897,7 @@ SdrObject* SwDrawContact::GetDrawObjectByAnchorFrame( const SwFrame& _rAnchorFra
return pRetDrawObj;
}
-void SwDrawContact::NotifyBackgrdOfAllVirtObjs(const tools::Rectangle* pOldBoundRect)
+void SwDrawContact::NotifyBackgroundOfAllVirtObjs(const tools::Rectangle* pOldBoundRect)
{
for(const auto& rpDrawVirtObj : maDrawVirtObjs)
{
@@ -1127,7 +1127,7 @@ void SwDrawContact::Changed_( const SdrObject& rObj,
lcl_NotifyBackgroundOfObj( *this, rObj, pOldBoundRect );
// --> #i36181# - background of 'virtual'
// drawing objects have also been notified.
- NotifyBackgrdOfAllVirtObjs( pOldBoundRect );
+ NotifyBackgroundOfAllVirtObjs( pOldBoundRect );
}
DisconnectFromLayout( false );
mbMasterObjCleared = true;
@@ -1426,7 +1426,7 @@ void SwDrawContact::SwClientNotify(const SwModify& rMod, const SfxHint& rHint)
ConnectToLayout(pNewAnchorFormat);
// notify background of drawing objects
lcl_NotifyBackgroundOfObj(*this, *GetMaster(), pOldRect);
- NotifyBackgrdOfAllVirtObjs(pOldRect);
+ NotifyBackgroundOfAllVirtObjs(pOldRect);
const SwFormatAnchor* pOldAnchorFormat = pLegacyHint->m_pOld ? lcl_getAnchorFormat(*pLegacyHint->m_pOld) : nullptr;
if(!pOldAnchorFormat || (pOldAnchorFormat->GetAnchorId() != pNewAnchorFormat->GetAnchorId()))
@@ -1482,7 +1482,7 @@ void SwDrawContact::SwClientNotify(const SwModify& rMod, const SfxHint& rHint)
assert(!"<SwDraw Contact::Modify(..)> - unhandled attribute?");
}
lcl_NotifyBackgroundOfObj(*this, *GetMaster(), nullptr);
- NotifyBackgrdOfAllVirtObjs(nullptr);
+ NotifyBackgroundOfAllVirtObjs(nullptr);
InvalidateObjs_(bUpdateSortedObjsList);
}
@@ -1651,7 +1651,7 @@ void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
{
const tools::Rectangle aOldRect( maAnchoredDrawObj.GetObjRectWithSpaces().SVRect() );
lcl_NotifyBackgroundOfObj( *this, *GetMaster(), &aOldRect );
- NotifyBackgrdOfAllVirtObjs( &aOldRect );
+ NotifyBackgroundOfAllVirtObjs( &aOldRect );
}
// remove 'virtual' drawing objects from writer
diff --git a/sw/source/core/frmedt/feshview.cxx b/sw/source/core/frmedt/feshview.cxx
index ee37c1d08423..9bdd23b856cf 100644
--- a/sw/source/core/frmedt/feshview.cxx
+++ b/sw/source/core/frmedt/feshview.cxx
@@ -3218,7 +3218,7 @@ void SwFEShell::CreateDefaultShape( SdrObjKind eSdrObjectKind, const tools::Rect
ImpEndCreate();
}
-/** SwFEShell::GetShapeBackgrd
+/** SwFEShell::GetShapeBackground
method determines background color of the page the selected drawing
object is on and returns this color.
If no color is found, because no drawing object is selected or ...,
@@ -3227,24 +3227,24 @@ void SwFEShell::CreateDefaultShape( SdrObjKind eSdrObjectKind, const tools::Rect
@returns an object of class Color
*/
-Color SwFEShell::GetShapeBackgrd() const
+Color SwFEShell::GetShapeBackground() const
{
Color aRetColor;
// check, if a draw view exists
- OSL_ENSURE( Imp()->GetDrawView(), "wrong usage of SwFEShell::GetShapeBackgrd - no draw view!");
+ OSL_ENSURE( Imp()->GetDrawView(), "wrong usage of SwFEShell::GetShapeBackground - no draw view!");
if( Imp()->GetDrawView() )
{
// determine list of selected objects
const SdrMarkList* pMrkList = &Imp()->GetDrawView()->GetMarkedObjectList();
// check, if exactly one object is selected.
- OSL_ENSURE( pMrkList->GetMarkCount() == 1, "wrong usage of SwFEShell::GetShapeBackgrd - no selected object!");
+ OSL_ENSURE( pMrkList->GetMarkCount() == 1, "wrong usage of SwFEShell::GetShapeBackground - no selected object!");
if ( pMrkList->GetMarkCount() == 1)
{
// get selected object
const SdrObject *pSdrObj = pMrkList->GetMark( 0 )->GetMarkedSdrObj();
// check, if selected object is a shape (drawing object)
- OSL_ENSURE( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr, "wrong usage of SwFEShell::GetShapeBackgrd - selected object is not a drawing object!");
+ OSL_ENSURE( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr, "wrong usage of SwFEShell::GetShapeBackground - selected object is not a drawing object!");
if ( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr )
{
// determine page frame of the frame the shape is anchored.
@@ -3257,7 +3257,7 @@ Color SwFEShell::GetShapeBackgrd() const
OSL_ENSURE( pPageFrame, "inconsistent model - no page!");
if ( pPageFrame )
{
- aRetColor = pPageFrame->GetDrawBackgrdColor();
+ aRetColor = pPageFrame->GetDrawBackgroundColor();
}
}
}
@@ -3280,19 +3280,19 @@ bool SwFEShell::IsShapeDefaultHoriTextDirR2L() const
bool bRet = false;
// check, if a draw view exists
- OSL_ENSURE( Imp()->GetDrawView(), "wrong usage of SwFEShell::GetShapeBackgrd - no draw view!");
+ OSL_ENSURE( Imp()->GetDrawView(), "wrong usage of SwFEShell::GetShapeBackground - no draw view!");
if( Imp()->GetDrawView() )
{
// determine list of selected objects
const SdrMarkList* pMrkList = &Imp()->GetDrawView()->GetMarkedObjectList();
// check, if exactly one object is selected.
- OSL_ENSURE( pMrkList->GetMarkCount() == 1, "wrong usage of SwFEShell::GetShapeBackgrd - no selected object!");
+ OSL_ENSURE( pMrkList->GetMarkCount() == 1, "wrong usage of SwFEShell::GetShapeBackground - no selected object!");
if ( pMrkList->GetMarkCount() == 1)
{
// get selected object
const SdrObject *pSdrObj = pMrkList->GetMark( 0 )->GetMarkedSdrObj();
// check, if selected object is a shape (drawing object)
- OSL_ENSURE( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr, "wrong usage of SwFEShell::GetShapeBackgrd - selected object is not a drawing object!");
+ OSL_ENSURE( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr, "wrong usage of SwFEShell::GetShapeBackground - selected object is not a drawing object!");
if ( dynamic_cast<const SwVirtFlyDrawObj*>( pSdrObj) == nullptr )
{
// determine page frame of the frame the shape is anchored.
diff --git a/sw/source/core/inc/pagefrm.hxx b/sw/source/core/inc/pagefrm.hxx
index 7156bec34157..73d81a6895b5 100644
--- a/sw/source/core/inc/pagefrm.hxx
+++ b/sw/source/core/inc/pagefrm.hxx
@@ -238,14 +238,14 @@ public:
bool IsInvalidAutoCompleteWords() const { return m_bInvalidAutoCmplWrds; }
bool IsInvalidWordCount() const { return m_bInvalidWordCount; }
- /** SwPageFrame::GetDrawBackgrdColor
+ /** SwPageFrame::GetDrawBackgroundColor
determine the color, that is respectively will be drawn as background
for the page frame.
@return reference to an instance of class Color
*/
- Color GetDrawBackgrdColor() const;
+ Color GetDrawBackgroundColor() const;
/** paint margin area of a page
diff --git a/sw/source/core/view/vdraw.cxx b/sw/source/core/view/vdraw.cxx
index 215f9e187326..cbc86e76a1c2 100644
--- a/sw/source/core/view/vdraw.cxx
+++ b/sw/source/core/view/vdraw.cxx
@@ -112,7 +112,7 @@ void SwViewShellImp::PaintLayer( const SdrLayerID _nLayerID,
// page background color is set as the background color at the
// outliner of the draw view. Only necessary for the layers
// hell and heaven
- Color aOldOutlinerBackgrdColor;
+ Color aOldOutlinerBackgroundColor;
// set default horizontal text direction on painting <hell> or
// <heaven>.
EEHorizontalTextDirection aOldEEHoriTextDir = EEHorizontalTextDirection::L2R;
@@ -124,7 +124,7 @@ void SwViewShellImp::PaintLayer( const SdrLayerID _nLayerID,
"incorrect usage of SwViewShellImp::PaintLayer: pPageBackgrdColor have to be set for painting layer <hell> or <heaven>");
if ( _pPageBackgrdColor )
{
- aOldOutlinerBackgrdColor =
+ aOldOutlinerBackgroundColor =
GetDrawView()->GetModel()->GetDrawOutliner().GetBackgroundColor();
GetDrawView()->GetModel()->GetDrawOutliner().SetBackgroundColor( *_pPageBackgrdColor );
}
@@ -151,7 +151,7 @@ void SwViewShellImp::PaintLayer( const SdrLayerID _nLayerID,
if ( (_nLayerID == rIDDMA.GetHellId()) ||
(_nLayerID == rIDDMA.GetHeavenId()) )
{
- GetDrawView()->GetModel()->GetDrawOutliner().SetBackgroundColor( aOldOutlinerBackgrdColor );
+ GetDrawView()->GetModel()->GetDrawOutliner().SetBackgroundColor( aOldOutlinerBackgroundColor );
GetDrawView()->GetModel()->GetDrawOutliner().SetDefaultHorizontalTextDirection( aOldEEHoriTextDir );
}
diff --git a/sw/source/filter/ww8/ww8graf.cxx b/sw/source/filter/ww8/ww8graf.cxx
index 195b646f85b4..06c568776143 100644
--- a/sw/source/filter/ww8/ww8graf.cxx
+++ b/sw/source/filter/ww8/ww8graf.cxx
@@ -2721,9 +2721,9 @@ SwFrameFormat* SwWW8ImplReader::Read_GrafLayer( tools::Long nGrafAnchorCp )
// both flags <bBelowText> and <bDrawHell> have to be set to move object into the background.
// #i46794# - it reveals that value of flag <bBelowText> can be neglected.
- const bool bMoveToBackgrd = pRecord->bDrawHell ||
+ const bool bMoveToBackground = pRecord->bDrawHell ||
((m_bIsHeader || m_bIsFooter) && aFSFA.nwr == 3);
- if ( bMoveToBackgrd )
+ if ( bMoveToBackground )
aFlySet.Put(SvxOpaqueItem(RES_OPAQUE,false));
OUString aObjName = pObject->GetName();
@@ -2766,7 +2766,7 @@ SwFrameFormat* SwWW8ImplReader::Read_GrafLayer( tools::Long nGrafAnchorCp )
if (!bDone)
{
sw::util::SetLayer aSetLayer(m_rDoc);
- if ( bMoveToBackgrd )
+ if ( bMoveToBackground )
aSetLayer.SendObjectToHell(*pObject);
else
aSetLayer.SendObjectToHeaven(*pObject);
diff --git a/sw/source/uibase/uiview/viewdraw.cxx b/sw/source/uibase/uiview/viewdraw.cxx
index 9d6d07e1deaf..3ecfa562009c 100644
--- a/sw/source/uibase/uiview/viewdraw.cxx
+++ b/sw/source/uibase/uiview/viewdraw.cxx
@@ -580,7 +580,7 @@ bool SwView::BeginTextEdit(SdrObject* pObj, SdrPageView* pPV, vcl::Window* pWin,
if(pView)
{
- Color aBackground(pSh->GetShapeBackgrd());
+ Color aBackground(pSh->GetShapeBackground());
pView->SetBackgroundColor(aBackground);
}
diff --git a/sw/source/core/layout/paintfrm.cxx b/sw/source/core/layout/paintfrm.cxx
index f5cb3c50ad1c..aec591d05c3c 100644
--- a/sw/source/core/layout/paintfrm.cxx
+++ b/sw/source/core/layout/paintfrm.cxx
@@ -1549,7 +1549,7 @@ static void lcl_SubtractFlys( const SwFrame *pFrame, const SwPageFrame *pPage,
gProp.pSRetoucheFly = nullptr;
}
-static void lcl_implDrawGraphicBackgrd(const SvxBrushItem& _rBackgrdBrush,
+static void lcl_implDrawGraphicBackground(const SvxBrushItem& _rBackgrdBrush,
vcl::RenderContext& _rOut,
const SwRect& _rAlignedPaintRect,
const GraphicObject& _rGraphicObj,
@@ -1609,7 +1609,7 @@ static void lcl_implDrawGraphicBackgrd(const SvxBrushItem& _rBackgrdBrush,
* background graphics. Previously, this code was integrated in method
* <lcl_DrawGraphic>.
* Method implemented as an inline, checking the conditions and calling method
* method <lcl_implDrawGraphicBackgrd(..)> for the intrinsic drawing.
*
* @param _rBackgrdBrush
* background brush contain the color the background has to be drawn.
@@ -1631,7 +1631,7 @@ static void lcl_implDrawGraphicBackgrd(const SvxBrushItem& _rBackgrdBrush,
* @param _bBackgrdAlreadyDrawn
* boolean (optional; default: false) indicating, if the background is already drawn.
*/
-static void lcl_DrawGraphicBackgrd( const SvxBrushItem& _rBackgrdBrush,
+static void lcl_DrawGraphicBackground( const SvxBrushItem& _rBackgrdBrush,
OutputDevice& _rOut,
const SwRect& _rAlignedPaintRect,
const GraphicObject& _rGraphicObj,
@@ -1648,7 +1648,7 @@ static void lcl_DrawGraphicBackgrd( const SvxBrushItem& _rBackgrdBrush,
( _rGraphicObj.IsTransparent() || _rGraphicObj.GetType() == GraphicType::NONE )
)
{
- lcl_implDrawGraphicBackgrd( _rBackgrdBrush, _rOut, _rAlignedPaintRect, _rGraphicObj, properties );
+ lcl_implDrawGraphicBackground( _rBackgrdBrush, _rOut, _rAlignedPaintRect, _rGraphicObj, properties );
}
}
@@ -1663,7 +1663,7 @@ static void lcl_DrawGraphicBackgrd( const SvxBrushItem& _rBackgrdBrush,
* Use align rectangle for drawing graphic Pixel-align coordinates for
* drawing graphic
* Outsource code for drawing background of the graphic
* with a background color in method <lcl_DrawGraphicBackgrd>
*
* Also, change type of <bGrfNum> and <bClip> from <bool> to <bool>
*/
@@ -1691,7 +1691,7 @@ static void lcl_DrawGraphic( const SvxBrushItem& rBrush, vcl::RenderContext &rOu
GraphicObject *pGrf = const_cast<GraphicObject*>(rBrush.GetGraphicObject());
// Outsource drawing of background with a background color
- ::lcl_DrawGraphicBackgrd( rBrush, rOutDev, aAlignedGrfRect, *pGrf, bGrfNum, properties, bBackgrdAlreadyDrawn );
+ ::lcl_DrawGraphicBackground( rBrush, rOutDev, aAlignedGrfRect, *pGrf, bGrfNum, properties, bBackgrdAlreadyDrawn );
// Because for drawing a graphic left-top-corner and size coordinates are
// used, these coordinates have to be determined on pixel level.
@@ -1917,7 +1917,7 @@ void DrawGraphic(
SwRect aAlignedPaintRect = rOut;
::SwAlignRect( aAlignedPaintRect, &rSh, &rOutDev );
// draw background color for aligned paint rectangle
- lcl_DrawGraphicBackgrd( *pBrush, rOutDev, aAlignedPaintRect, *pGraphicObj, bGrfNum, gProp );
+ lcl_DrawGraphicBackground( *pBrush, rOutDev, aAlignedPaintRect, *pGraphicObj, bGrfNum, gProp );
// set left-top-corner of background graphic to left-top-corner of the
// area, from which the background brush is determined.
@@ -3201,7 +3201,7 @@ void SwRootFrame::PaintSwFrame(vcl::RenderContext& rRenderContext, SwRect const&
// determine background color of page for <PaintLayer> method
// calls, paint <hell> or <heaven>
- const Color aPageBackgrdColor(pPage->GetDrawBackgrdColor());
+ const Color aPageBackgrdColor(pPage->GetDrawBackgroundColor());
pPage->PaintBaBo( aPaintRect, pPage );
@@ -3816,12 +3816,12 @@ bool SwFlyFrame::IsBackgroundTransparent() const
if ( !bBackgroundTransparent &&
GetFormat()->IsBackgroundBrushInherited() )
{
- const SvxBrushItem* pBackgrdBrush = nullptr;
+ const SvxBrushItem* pBackgroundBrush = nullptr;
std::optional<Color> xSectionTOXColor;
SwRect aDummyRect;
drawinglayer::attribute::SdrAllFillAttributesHelperPtr aFillAttributes;
- if ( GetBackgroundBrush( aFillAttributes, pBackgrdBrush, xSectionTOXColor, aDummyRect, false, /*bConsiderTextBox=*/false) )
+ if ( GetBackgroundBrush( aFillAttributes, pBackgroundBrush, xSectionTOXColor, aDummyRect, false, /*bConsiderTextBox=*/false) )
{
if ( xSectionTOXColor &&
(xSectionTOXColor->IsTransparent()) &&
@@ -3833,17 +3833,17 @@ bool SwFlyFrame::IsBackgroundTransparent() const
{
bBackgroundTransparent = aFillAttributes->isTransparent();
}
- else if ( pBackgrdBrush )
+ else if ( pBackgroundBrush )
{
- if ( (pBackgrdBrush->GetColor().IsTransparent()) &&
- (pBackgrdBrush->GetColor() != COL_TRANSPARENT) )
+ if ( (pBackgroundBrush->GetColor().IsTransparent()) &&
+ (pBackgroundBrush->GetColor() != COL_TRANSPARENT) )
{
bBackgroundTransparent = true;
}
else
{
const GraphicObject *pTmpGrf =
- pBackgrdBrush->GetGraphicObject();
+ pBackgroundBrush->GetGraphicObject();
if ( pTmpGrf &&
(pTmpGrf->GetAttr().IsTransparent())
)
@@ -7085,7 +7085,7 @@ void SwLayoutFrame::RefreshExtraData( const SwRect &rRect ) const
*
* @return Color
*/
-Color SwPageFrame::GetDrawBackgrdColor() const
+Color SwPageFrame::GetDrawBackgroundColor() const
{
const SvxBrushItem* pBrushItem;
std::optional<Color> xDummyColor;
@@ -7190,7 +7190,7 @@ void SwFrame::Retouch( const SwPageFrame * pPage, const SwRect &rRect ) const
ResetRetouche();
if ( rRetouche.HasArea() )
{
- const Color aPageBackgrdColor(pPage->GetDrawBackgrdColor());
+ const Color aPageBackgrdColor(pPage->GetDrawBackgroundColor());
const IDocumentDrawModelAccess& rIDDMA = pSh->getIDocumentDrawModelAccess();
// --> OD #i76669#
SwViewObjectContactRedirector aSwRedirector( *pSh );
@@ -7510,7 +7510,7 @@ Graphic SwFlyFrameFormat::MakeGraphic( ImageMap* pMap, const std::optional<Size>
// determine page, fly frame is on
const SwPageFrame* pFlyPage = pFly->FindPageFrame();
- const Color aPageBackgrdColor(pFlyPage->GetDrawBackgrdColor());
+ const Color aPageBackgrdColor(pFlyPage->GetDrawBackgroundColor());
const IDocumentDrawModelAccess& rIDDMA = pSh->getIDocumentDrawModelAccess();
// --> OD #i76669#
SwViewObjectContactRedirector aSwRedirector( *pSh );
@@ -1609,7 +1609,7 @@ static void lcl_implDrawGraphicBackgrd(const SvxBrushItem& _rBackgrdBrush,
* <lcl_DrawGraphic>.
* Method implemented as an inline, checking the conditions and calling method
- * method <lcl_implDrawGraphicBackgrd(..)> for the intrinsic drawing.
+ * method <lcl_implDrawGraphicBackground(..)> for the intrinsic drawing.
*
* @param _rBackgrdBrush
@@ -1663,7 +1663,7 @@ static void lcl_DrawGraphicBackgrd( const SvxBrushItem& _rBackgrdBrush,
* drawing graphic
* Outsource code for drawing background of the graphic
- * with a background color in method <lcl_DrawGraphicBackgrd>
+ * with a background color in method <lcl_DrawGraphicBackground>
*
* Also, change type of <bGrfNum> and <bClip> from <bool> to <bool>